# ../addons/eventscripts/gungame/scripts/custom/gg_knives_only/gg_knives_only.py

# ============================================================================
# >> IMPORTS
# ============================================================================
# Eventscripts Imports
import es
import gamethread
from playerlib import getPlayer
import spe

# GunGame Imports
from gungame51.core.addons.shortcuts import AddonInfo
from gungame51.core.players import Player
from gungame51.core.addons import load as addon_load
from gungame51.core.addons import unload as addon_unload
from gungame51.core.addons import PriorityAddon

# ============================================================================
# >> ADDON REGISTRATION/INFORMATION
# ============================================================================
info = AddonInfo()
info.name = "gg_knives_only"
info.title = "GG Knives Only"
info.author = "Warren Alpert"
info.version = "0.4"
info.requires = ["gg_dead_strip"]

# ============================================================================
# >> GLOBAL VARIABLES
# ============================================================================
gg_turbo = es.ServerVar("gg_turbo")
# Back up gg_turbo
gg_turbo_backup = int(gg_turbo)

# ============================================================================
# >> LOAD & UNLOAD
# ============================================================================
def load():
    # If turbo is loaded, unload it
    if gg_turbo_backup:
        gamethread.delayedname(1, "gg_knives_only_turbo_var", gg_turbo.set, 0)
        # Delay the unload in case it will be loaded by gungame soon
        gamethread.delayedname(1, "gg_knives_only_turbo", addon_unload,
                                                                    "gg_turbo")

    # If we are not in warmup, remove all weapons other than knives
    if not "gg_warmup_round" in PriorityAddon():
        for userid in es.getUseridList():
            playerWeapons = spe.getWeaponDict(userid)
            for weapon in playerWeapons:
                if weapon == "weapon_knife":
                    continue

                # If the player is on hegrenade level, and the weapon is an
                # hegrenade, do not remove it
                if Player(userid).weapon == "hegrenade" and weapon == \
                                                            "weapon_hegrenade":
                    continue

                spe.dropWeapon(userid, weapon)
                spe.removeEntityByInstance(playerWeapons[weapon]["instance"])

        es.dbgmsg(0, "Loaded: %s" % info.name)

def unload():
    # If turbo was loaded before, load it back
    if gg_turbo_backup:
        # The one second delay to unload turbo never got to happen, it was
        # unloaded too quickly
        if gg_turbo:
            gamethread.cancelDelayed("gg_knives_only_turbo_var")
            gamethread.cancelDelayed("gg_knives_only_turbo")
        else:
            gg_turbo.set(1)
            addon_load("gg_turbo")

    # Give all players their weapons
    for userid in es.getUseridList():
        # If they are dead, spectating, or unassigned, stop here
        if getPlayer(userid).isdead or es.getplayerteam(userid) < 2:
            continue

        Player(userid).give_weapon()

    es.dbgmsg(0, "Unloaded: %s" % info.name)

# ============================================================================
# >> GAME EVENTS
# ============================================================================
def gg_levelup(event_var):
    attacker = event_var["attacker"]

    # If turbo was normally loaded
    if gg_turbo_backup:
        # If the player leveled up to hegrenade level
        if Player(attacker).weapon == "hegrenade":
            # Give them a grenade.
            spe.giveNamedItem(attacker, "weapon_hegrenade")

            # Make them use the grenade
            es.server.queuecmd('es_xsexec %s "use weapon_hegrenade"' % (
                                                                attacker))

def item_pickup(event_var):
    weapon = event_var["item"]
    userid = event_var["userid"]

    # If the weapon they picked up is a knife, stop here
    if weapon == "knife":
        return

    # If the player is on hegrenade level, and the weapon they picked up is an
    # hegrenade, stop here
    if Player(userid).weapon == "hegrenade" and weapon == "hegrenade":
        return

    weapon = "weapon_%s" % weapon

    # Get the weapon instance, and remove it
    instance = spe.ownsWeapon(userid, weapon)
    if instance:
        spe.dropWeapon(userid, weapon)
        spe.removeEntityByInstance(instance)